# Rocket

`Rocket` is a Python library for ..........

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `package_name`.

```bash
pip install package_name
```

## Usage

```python
import rocket

# to move rocket to corr x, y
rocket.move_rocket(x, y)

# returns 'geese'
package_name.module_name('goose')

# returns 'phenomenon'
package_name.module_name('phenomena')
```

## License

[MIT](https://choosealicense.com/licenses/mit/)
